@@ -23,10 +23,7 @@ from typing import TYPE_CHECKING, Any
 
 from gremlin_python.driver.client import Client
 
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 
 if TYPE_CHECKING:
     from airflow.models import Connection
@@ -70,11 +67,11 @@ class GremlinHook(BaseHook):
 
         self.connection = self.get_connection(self.gremlin_conn_id)
 
-        uri = self.get_uri(self.connection)  # type: ignore[arg-type]
+        uri = self.get_uri(self.connection)
         self.log.info("Connecting to URI: %s", uri)
 
         self.client = self.get_client(
-            self.connection,  # type: ignore[arg-type]
+            self.connection,
             self.traversal_source,
             uri,
             message_serializer=serializer,
